models = [{
    "id": 5,
    "type": 7,
    "name": "claude-3-haiku-20240307",
    "showName": "Claude Mezzo \r\n",
    "maxToken": 180000,
    "searchFlag": 0,
    "remark": "混合模型，根据对话自动选择适当的 Claude3 模型，当前预览版，支持自动联网及识别对话中的图像\r\n"
}, {
    "id": 6,
    "type": 6,
    "name": "claude-3-opus-20240229",
    "showName": "Claude3 Opus",
    "maxToken": 180000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 7,
    "type": 5,
    "name": "mistralai/mixtral-8x22b-instruct",
    "showName": "Mixtral Forte\r\n",
    "maxToken": 30768,
    "searchFlag": 0,
    "remark": "根据对话自动选择适当的Mixtral模型，当前预览版，支持对话、自动联网，建议使用英文对话"
}, {
    "id": 9,
    "type": 2,
    "name": "gpt-4-turbo-2024-04-09",
    "showName": "GPT Mezzo\r\n",
    "maxToken": 118000,
    "searchFlag": 0,
    "remark": "联网模型，包含最新的 GPT-4o 及 自动联网"
}, {
    "id": 10,
    "type": 0,
    "name": "gpt-4-turbo-2024-04-09",
    "showName": "GPT Forte\r\n",
    "maxToken": 118000,
    "searchFlag": 0,
    "remark": "混合模型，根据对话自动选择 GPT4 或 GPT-4o 模型，当前预览版，支持对话、自动联网、图像识别及生成"
}, {
    "id": 11,
    "type": 3,
    "name": "dall-e-3",
    "showName": "DALL · E3",
    "maxToken": 4096,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 12,
    "type": 8,
    "name": "meta-llama/llama-3-70b-instruct",
    "showName": "Llama3 70B",
    "maxToken": 30768,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 13,
    "type": 9,
    "name": "google/gemini-pro-1.5",
    "showName": "Gemini 1.5 Pro",
    "maxToken": 1000000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 14,
    "type": 10,
    "name": "deepseek-chat",
    "showName": "Deepseek",
    "maxToken": 1180000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 15,
    "type": 9,
    "name": "google/gemini-flash-1.5",
    "showName": "Gemini-flash",
    "maxToken": 100000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 16,
    "type": 11,
    "name": "gpt-4o-2024-05-13",
    "showName": "GPT4o",
    "maxToken": 128000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 17,
    "type": 12,
    "name": "claude-3-opus-20240229",
    "showName": "Claude3 Opus(100K)",
    "maxToken": 90000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 18,
    "type": 13,
    "name": "Stable Image Ultra",
    "showName": "Stable Diffusion 3 Ultra",
    "maxToken": 10000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 19,
    "type": 15,
    "name": "claude-3-5-sonnet-20240620",
    "showName": "Claude 3.5 Sonnet",
    "maxToken": 180000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 20,
    "type": 16,
    "name": "gpt-4o-mini-2024-07-18",
    "showName": "GPT4o-mini",
    "maxToken": 118000,
    "searchFlag": 0,
    "remark": None
}, {
    "id": 21,
    "type": 17,
    "name": "meta-llama/llama-3.1-405b-instruct",
    "showName": "Llama3.1 405B",
    "maxToken": 121072,
    "searchFlag": 0,
    "remark": None
}]
